@@ -11,22 +11,51 @@ pub use ctags::ctags_cmd::CmdCtags;
 pub use ctags::ctags_opt::Opt;
 pub use ctags::ctags_parser::CtagsParser;
 pub use plantuml::plantuml_render::PlantUmlRender;
+use std::path::Path;
 
 pub mod ctags;
 pub mod plantuml;
 pub mod coco_struct;
 
+/// Returns Vec<ClassInfo> with the given path.
+///
+/// # Arguments
+///
+/// * `path` - CODE PATH
+///
+/// # Examples
+///
+/// ```
+/// use modeling::{by_dir, PlantUmlRender};
+///
+/// let classes = by_dir("src/");
+/// let puml = PlantUmlRender::render(&classes);
+/// ```
+pub fn by_dir<P: AsRef<Path>>(path: P) -> Vec<ClassInfo> {
+    let origin_files = files_from_path(path);
 
-pub fn analysis_by_dir(url_str: &str) -> Vec<ClassInfo> {
-    let origin_files = files_from_path(url_str);
-    let thread = count_thread(&origin_files);
+    by_files(origin_files)
+}
 
+/// Returns Vec<ClassInfo> with the given files.
+///
+/// # Arguments
+///
+/// * `files` - code files in string
+///
+/// # Examples
+///
+/// ```
+/// use modeling::{by_files, PlantUmlRender};
+///
+/// let classes = by_files(files);
+/// let puml = PlantUmlRender::render(&classes);
+/// ```
+pub fn by_files(files: Vec<String>) -> Vec<ClassInfo> {
+    let thread = count_thread(&files);
     let opt = build_opt(thread);
 
-    let files = files_by_thread(origin_files, &opt);
-    let classes = run_ctags(&opt, &files);
-
-    classes
+    run_ctags(&opt, &files_by_thread(files, &opt))
 }
 
 fn count_thread(origin_files: &Vec<String>) -> usize {
@@ -56,7 +85,7 @@ fn run_ctags(opt: &Opt, files: &Vec<String>) -> Vec<ClassInfo> {
     classes
 }
 
-fn files_from_path(path: &str) -> Vec<String> {
+fn files_from_path<P: AsRef<Path>>(path: P) -> Vec<String> {
     let mut origin_files = vec![];
     for result in Walk::new(path) {
         if let Ok(entry) = result {
@@ -88,13 +117,14 @@ fn build_opt(thread: usize) -> Opt {
 #[cfg(test)]
 mod tests {
     use std::path::PathBuf;
-    use crate::{analysis_by_dir, PlantUmlRender};
+    use crate::{by_dir, PlantUmlRender};
 
     pub fn ctags_fixtures_dir() -> PathBuf {
         let root_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR"));
         let ctags_dir = root_dir.join("_fixtures")
             .join("ctags")
-            .join("source");
+            .join("source")
+            .join("animal.ts");
 
         return ctags_dir;
     }
@@ -103,9 +133,14 @@ mod tests {
     #[test]
     fn should_run_struct_analysis() {
         let path = format!("{}", ctags_fixtures_dir().display());
-        let vec = analysis_by_dir(path.as_str());
+        let vec = by_dir(path);
+
+        assert_eq!(3, vec.len());
         let result = PlantUmlRender::render(&vec);
 
         println!("{}", result);
+        assert!(result.contains("class Animal"));
+        assert!(result.contains("class Horse extends Animal"));
+        assert!(result.contains("class Snake extends Animal "));
     }
 }
\ No newline at end of file
